﻿

local moduleName = "UnitName"



----------------------------
--      Localization      --
----------------------------

local L = AceLibrary("AceLocale-2.2"):new("BunchOfBars"..moduleName)

L:RegisterTranslations("enUS", function() return {
	[moduleName] = "Unit Name",

	["Text Format"] = true,

	["Predefined Formats"] = true,
	["Choose from a set of prefedined formats."] = true,

	["Text Justification"] = true,
	["Set the horizontal text justification."] = true
} end)

L:RegisterTranslations("koKR", function() return {
	[moduleName] = "유닛 이름",

	["Text Format"] = "글자 설정",

	["Predefined Formats"] = "정의된 설정",
	["Choose from a set of prefedined formats."] = "미리 정의된 설정을 사용합니다.",

	["Text Justification"] = "글자 정의",
	["Set the horizontal text justification."] = "표시하고 싶은 글자를 정의합니다."
} end)


----------------------------------
--      Local Declaration      --
----------------------------------

local DogTag = AceLibrary("DogTag-1.0")


local formats = {
	["[[AFK:Offline]:Trunc(3):Paren:Red] [Name:ClassColor]"] = "'(AFK/Offline)' 'Classcolored Name'",
	["[[AFK:Offline]?Name:Gray!Name:ClassColor]"]            = "'Status colored Name'"
}

local formatsdesc = { }
do
	for k in pairs(formats) do
		formatsdesc[k] = k
	end
end



----------------------------------
--      Module Declaration      --
----------------------------------

local plugin = BunchOfBars:NewModule(moduleName, "AceEvent-2.0")

plugin.revision = tonumber(("$Revision: 39544 $"):match("%d+"))

plugin.options = {
	name = L[moduleName],
	args = {
		format = {
			type  = "text",
			name  = L["Text Format"],
			desc  = L["Text Format"],
			usage = "DogTag-1.0 tags. See http://www.wowace.com/wiki/DogTag-1.0",
			get   = "GetSetFormat",
			set   = "GetSetFormat"
		},
		preformats = {
			type  = "text",
			name  = L["Predefined Formats"],
			desc  = L["Choose from a set of prefedined formats."],
			usage = "",
			validate     = formats,
			validateDesc = formatsdesc,
			get = "GetSetFormat",
			set = "GetSetFormat"
		},
		justification = {
			type     = "text",
			name     = L["Text Justification"],
			desc     = L["Set the horizontal text justification."],
			usage    = "",
			validate = { "LEFT", "CENTER", "RIGHT" },
			get      = "GetSetTextJustification",
			set      = "GetSetTextJustification"
		}
	}
}

plugin.defaultDB = {
	position = 1,

	format        = next(formats),
	justification = "RIGHT"
}



----------------------------------
--      Module Functions        --
----------------------------------

function plugin:OnCreate(frame)
	local font = frame:CreateFontString(nil, "OVERLAY")
	font:SetFontObject(GameFontNormalSmall)
	font:SetWidth(75)
	font:SetHeight(14)
	font:SetVertexColor(1, 1, 1, 1)

	--self:ScheduleEvent(self.OnUpdate, 5, self, frame, font) -- for DogTag which seems to need some late update

	return font
end


function plugin:OnUpdate(frame, font)
	font:SetJustifyH(self.db.profile.justification)

	DogTag:RegisterFontString(font, frame, frame.unit, self.db.profile.format)
end


function plugin:OnInactive(frame, font)
	DogTag:UnregisterFontString(font)
end


function plugin:GetSetFormat(v)
	if type(v) == "nil" then return self.db.profile.format end

	-- this check is to assure we don't reschedule the event to often
	if self.db.profile.format ~= v then
		self.db.profile.format = v

		self:UpdateAll()
	end
end


function plugin:GetSetTextJustification(v)
	if type(v) == "nil" then return self.db.profile.justification end

	-- this check is to assure we don't reschedule the event to often
	if self.db.profile.justification ~= v then
		self.db.profile.justification = v

		self:UpdateAll()
	end
end
